@@ -1,15 +1,18 @@
 package Bijection;
-use 5.006; use strict; use warnings; our $VERSION = '0.01';
+use 5.006; use strict; use warnings; our $VERSION = '0.02';
 use Import::Export; use base qw/Import::Export/;
 use Carp qw/croak/;
-our %EX = (biject => [qw/all/], inverse => [qw/all/]);
+our %EX = (biject => [qw/all/], inverse => [qw/all/], bijection_set => [qw/all/]);
 
 our (@ALPHA, $COUNT, %INDEX);
 BEGIN {
-	@ALPHA = qw/b c d f g h j k l m n p q r s t v w x y z B C D F G H J K L M N P Q R S T V W X Y Z 0 1 2 3 4 5 6 7 8 9/;
-	$COUNT = @ALPHA;
-	my $index = -1;
-	%INDEX = map +( $_ => ++$index ), @ALPHA; 
+	sub bijection_set {
+		@ALPHA = @_; 
+		$COUNT = @ALPHA;
+		my $index = -1;
+		%INDEX = map +( $_ => ++$index ), @ALPHA;
+	}
+	bijection_set(qw/b c d f g h j k l m n p q r s t v w x y z B C D F G H J K L M N P Q R S T V W X Y Z 0 1 2 3 4 5 6 7 8 9/);
 }
 
 sub biject {
@@ -21,7 +24,7 @@ sub biject {
 
 sub inverse {
 	my ($out, $id) = (@_, 0);
-    defined $INDEX{$_} && do { $id = $id * $COUNT + $INDEX{$_}; 1; } or croak "invalid character $_ in $out" for (split //, $out);
+	defined $INDEX{$_} && do { $id = $id * $COUNT + $INDEX{$_}; 1; } or croak "invalid character $_ in $out" for (split //, $out);
 	$id - $COUNT;
 }
 
@@ -31,11 +34,11 @@ __END__
 
 =head1 NAME
 
-Bijection - Bijection.
+Bijection - Bijection of an integer.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -45,12 +48,23 @@ Quick summary of what the module does.
 
 Perhaps a little code snippet.
 
-	use Bijection qw/all/;
+	use Bijection qw/biject inverse/;
 
 	my $int = 1;
 	my $string = biject($int);
 	inverse($string) == $int;
 
+	....
+
+	use Bijection qw/all/;
+
+	bijection_set(reverse @Bijection::ALPHA[9 .. $#Bijection::ALPHA]);
+
+	my $int = 2;
+	my $string = biject($int);
+	inverse($string) == $int;
+
+
 =head1 EXPORT
 
 =head2 biject
@@ -61,6 +75,10 @@ Perhaps a little code snippet.
 
 =cut
 
+=head2 bijection_set
+
+=cut
+
 =head1 AUTHOR
 
 lnation, C<< <thisusedtobeanemail at gmail.com> >>
